package com.ruoyi.learn.service;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.dz.domain.DzSubject;
import com.ruoyi.learn.domain.LearnWrongBook;

/**
 * 学生错题本Service接口
 *
 * @author ruoyi
 * @date 2025-09-25
 */
public interface ILearnWrongBookService
{
    /**
     * 查询学生错题本
     *
     * @param wrongId 学生错题本主键
     * @return 学生错题本
     */
    public LearnWrongBook selectLearnWrongBookByWrongId(Long wrongId);

    /**
     * 查询学生错题本列表
     *
     * @param learnWrongBook 学生错题本
     * @return 学生错题本集合
     */
    public List<LearnWrongBook> selectLearnWrongBookList(LearnWrongBook learnWrongBook);

    /**
     * 新增学生错题本
     *
     * @param learnWrongBook 学生错题本
     * @return 结果
     */
    public int insertLearnWrongBook(LearnWrongBook learnWrongBook);

    /**
     * 修改学生错题本
     *
     * @param learnWrongBook 学生错题本
     * @return 结果
     */
    public int updateLearnWrongBook(LearnWrongBook learnWrongBook);

    /**
     * 批量删除学生错题本
     *
     * @param wrongIds 需要删除的学生错题本主键集合
     * @return 结果
     */
    public int deleteLearnWrongBookByWrongIds(Long[] wrongIds);

    /**
     * 删除学生错题本信息
     *
     * @param wrongId 学生错题本主键
     * @return 结果
     */
    public int deleteLearnWrongBookByWrongId(Long wrongId);

    public List<DzSubject> findSubject();

    public List<LearnWrongBook> findWrongQuestions(Long subjectId, Date start, Date end);

    public List<LearnWrongBook> findWrongExaminees(Long wrongId);

    public int deleteByQuestion(Long studentId, Long questionId);
}
